==> generator-react-2.2.0.tgz: package/README.md <==
# Yeoman generator for Rapid Proof-of-Concepts in React

[![npm](https://img.shields.io/npm/v/@rpoc/generator-react.svg)](https://www.npmjs.com/package/@rpoc/generator-react)
[![npm](https://img.shields.io/npm/dt/@rpoc/generator-react.svg)](https://www.npmjs.com/package/@rpoc/generator-react)
[![NpmLicense](https://img.shields.io/npm/l/@rpoc/generator-react.svg)](https://opensource.org/licenses/MIT)

A collection of React generators for developing Rapid Proof-of-Concepts.

## Installation

```bash
npm install -g yo @rpoc/generator-react
```

## Generators

### Base

- Axios
- Chai
- CI & CD with circleci
- Enzyme
- Eslint
- MobX with decorators
- Mocha
- Moment
- Nyc
- React Router DOM

```bash
create-react-app myapp
cd myapp
yo @rpoc/react:base
```

### CoreUI

Sets up a "CoreUI – A free Bootstrap admin template" for React

Requires `@rpoc/react:base` generator to have been run

- Bootstrap
- ChartJS
- CoreJS
- CoreUI
- Fontawesome
- Reactstrap

```bash
yo @rpoc/react:coreui
```

### CRUD

Add a Resource with create, read, update, and delete Stores, Routes, Navigations, and Views.

Requires `@rpoc/react:coreui` generator to have been run

```
yo @rpoc/react:crud
```

### AWS Amplify

Adds aws-amplify with Auth and Storage boilerplate config in src/index.js.

Works with and without `@rpoc/react:coreui`.

Requires `@rpoc/react:base` generator to have been run.

```
yo @rpoc/react:amplify
```

#### AWS Amplify Resources & Documentation

- [AWS Amplify](https://aws-amplify.github.io/)
- [AWS Amplify Authentication](https://aws-amplify.github.io/amplify-js/media/authentication_guide)
- [AWS Amplify Storage](https://aws-amplify.github.io/amplify-js/media/storage_guide)
- [AWS Amplify React](https://aws-amplify.github.io/amplify-js/media/react_guide)

## LICENSE

Copyright 2018 Robert Brewitz Borg

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> generator-react-2.2.1.tgz: package/README.md <==
# Yeoman generator for Rapid Proof-of-Concepts in React

[![npm](https://img.shields.io/npm/v/@rpoc/generator-react.svg)](https://www.npmjs.com/package/@rpoc/generator-react)
[![npm](https://img.shields.io/npm/dt/@rpoc/generator-react.svg)](https://www.npmjs.com/package/@rpoc/generator-react)
[![NpmLicense](https://img.shields.io/npm/l/@rpoc/generator-react.svg)](https://opensource.org/licenses/MIT)

A collection of React generators for developing Rapid Proof-of-Concepts.

## Node version

Using the latest major LTS node version, currently Node 8.

## Installation

```bash
nvm use 8
npm install -g create-react-app yo @rpoc/generator-react
```

## Generators

### Base

- Axios
- CI & CD with circleci
- Chai
- Editorconfig
- Enzyme
- Eslint
- MobX with decorators
- Mocha
- Moment
- Nyc
- React Router DOM

```bash
create-react-app myapp
cd myapp
yo @rpoc/react:base
```

### CoreUI

Sets up a "CoreUI – A free Bootstrap admin template" for React

Requires `@rpoc/react:base` generator to have been run

- Bootstrap
- ChartJS
- CoreJS
- CoreUI
- Fontawesome
- Reactstrap

```bash
yo @rpoc/react:coreui
```

### CRUD

Add a Resource with create, read, update, and delete Stores, Routes, Navigations, and Views.

Requires `@rpoc/react:coreui` generator to have been run

```
yo @rpoc/react:crud
```

### AWS Amplify

Adds aws-amplify with Auth and Storage boilerplate config in src/index.js.

Works with and without `@rpoc/react:coreui`.

Requires `@rpoc/react:base` generator to have been run.

```
yo @rpoc/react:amplify
```

#### AWS Amplify Resources & Documentation

- [AWS Amplify](https://aws-amplify.github.io/)
- [AWS Amplify Authentication](https://aws-amplify.github.io/amplify-js/media/authentication_guide)
- [AWS Amplify Storage](https://aws-amplify.github.io/amplify-js/media/storage_guide)
- [AWS Amplify React](https://aws-amplify.github.io/amplify-js/media/react_guide)

## LICENSE

Copyright 2018 Robert Brewitz Borg

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
